@@ -1,3 +1,4 @@
+import distro
 import logging
 import os
 import platform
@@ -6,7 +7,7 @@ import time
 import sys
 
 
-__version__ = '0.7'
+__version__ = '0.8'
 
 
 logger = logging.getLogger('usagestats')
@@ -45,7 +46,7 @@ def OPERATING_SYSTEM(stats, info):
     """
     info.append(('architecture', platform.machine().lower()))
     info.append(('distribution',
-                 "%s;%s" % (platform.linux_distribution()[0:2])))
+                 "%s;%s" % (distro.linux_distribution()[0:2])))
     info.append(('system',
                  "%s;%s" % (platform.system(), platform.release())))
 
